<?php

namespace App\Command;

use App\Entity\User;
use App\Entity\UserLog;
use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;

#[AsCommand(
    name: 'app:update-all-users-cron',
    description: 'Add a short description for your command',
)]
class UpdateAllUsersCronCommand extends Command
{
    private EntityManager $entityManager;

    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->entityManager = $entityManager;
        parent::__construct();
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);

        $em = $this->entityManager;
        $repo = $em->getRepository(User::class);

        $chunkSize = 100;
        $count = $repo->count([]);

        $io->progressStart($count);
        for ($i = 0; $i < $count; $i += $chunkSize) {
            $data = $repo->findBy([], null, $chunkSize, $i);
            if ($data == []) {
                break;
            }

            /** @var User */
            foreach ($data as $user) {
                $score = (int) $user->getScore();
                if ($score < 100 || $score > 900) {
                    $user->setLog(true);

                    $log = new UserLog();
                    $log->setScore($user->getScore());
                    $log->setUserId($user->getId());
                    
                    $em->persist($user);
                    $em->persist($log);
                } else if ($user->getLog()) {
                    $user->setLog(false);
                    $em->persist($user);
                }
            }

            $io->progressAdvance($chunkSize);

            $em->flush();
            $em->clear();
        }
        $io->progressFinish();

        return Command::SUCCESS;
    }
}
