<?php

namespace App\EventListener;

use Psr\Log\LoggerInterface;
use Symfony\Component\EventDispatcher\Attribute\AsEventListener;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\Security\Core\Security;

#[AsEventListener(event: RequestEvent::class)]
class RequestListener
{
    public function __construct(
        private Security $security,
        private LoggerInterface $logger
    ) {}
    public function onKernelRequest(RequestEvent $event): void
    {
        $req = $event->getRequest();
        
        if (!$event->isMainRequest()) {
            return;
        }
        if (!($req->isMethod('GET') || $req->isMethod('POST'))) {
            return;
        }
        if (!$req->getSession()->has(Security::LAST_USERNAME)) {
            return;
        }

        $user = $this->security->getUser();
        if ($user !== null) {
            $this->logger->info('Handled request for user with log flag', [ $req->getMethod(), $req->getUri(), $user->getUserIdentifier() ]);
        }
    }
}